@@ -19,7 +19,7 @@
 #' @inheritParams boost_tree
 #' @param mode A single character string for the type of model.
 #'  The only possible value for this model is "classification".
-#' @param penalty An non-negative number representing the total
+#' @param penalty A non-negative number representing the total
 #'  amount of regularization (`glmnet`, `keras`, and `spark` only).
 #'  For `keras` models, this corresponds to purely L2 regularization
 #'  (aka weight decay) while the other models can be a combination
@@ -41,6 +41,13 @@
 #'
 #' @section Engine Details:
 #'
+#' The standardized parameter names in parsnip can be mapped to their original
+#' names in each engine:
+#'
+#' ```{r echo = FALSE}
+#' convert_args("multinom_reg")
+#' ```
+#'
 #' Engines may have pre-set default arguments when executing the
 #'  model fit call.  For this type of
 #'  model, the template of the fit calls are:
@@ -84,7 +91,7 @@
 #'  separately saved to disk. In a new session, the object can be
 #'  reloaded and reattached to the `parsnip` object.
 #'
-#' @seealso [[fit()]
+#' @seealso [fit()]
 #' @examples
 #' multinom_reg()
 #' # Parameters can be represented by a placeholder:
@@ -183,9 +190,9 @@ check_args.multinom_reg <- function(object) {
   args <- lapply(object$args, rlang::eval_tidy)
 
   if (all(is.numeric(args$penalty)) && any(args$penalty < 0))
-    stop("The amount of regularization should be >= 0", call. = FALSE)
+    rlang::abort("The amount of regularization should be >= 0.")
   if (is.numeric(args$mixture) && (args$mixture < 0 | args$mixture > 1))
-    stop("The mixture proportion should be within [0,1]", call. = FALSE)
+    rlang::abort("The mixture proportion should be within [0,1].")
 
   invisible(object)
 }
@@ -262,7 +269,7 @@ predict._multnet <-
 multi_predict._multnet <-
   function(object, new_data, type = NULL, penalty = NULL, ...) {
     if (any(names(enquos(...)) == "newdata"))
-      stop("Did you mean to use `new_data` instead of `newdata`?", call. = FALSE)
+      rlang::abort("Did you mean to use `new_data` instead of `newdata`?")
 
     if (is_quosure(penalty))
       penalty <- eval_tidy(penalty)
@@ -281,7 +288,7 @@ multi_predict._multnet <-
     if (is.null(type))
       type <- "class"
     if (!(type %in% c("class", "prob", "link", "raw"))) {
-      stop("`type` should be either 'class', 'link', 'raw', or 'prob'.", call. = FALSE)
+      rlang::abort("`type` should be either 'class', 'link', 'raw', or 'prob'.")
     }
     if (type == "prob")
       dots$type <- "response"
@@ -346,11 +353,12 @@ predict_raw._multnet <- function(object, new_data, opts = list(), ...) {
 # This checks as a pre-processor in the model data object
 check_glmnet_lambda <- function(dat, object) {
   if (length(object$fit$lambda) > 1)
-    stop(
+    rlang::abort(
+      glue::glue(
       "`predict()` doesn't work with multiple penalties (i.e. lambdas). ",
       "Please specify a single value using `penalty = some_value` or use ",
-      "`multi_predict()` to get multiple predictions per row of data.",
-      call. = FALSE
+      "`multi_predict()` to get multiple predictions per row of data."
+      )
     )
   dat
 }
