@@ -48,6 +48,13 @@
 #'
 #' @section Engine Details:
 #'
+#' The standardized parameter names in parsnip can be mapped to their original
+#' names in each engine:
+#'
+#' ```{r echo = FALSE}
+#' convert_args("nearest_neighbor")
+#' ```
+#'
 #' Engines may have pre-set default arguments when executing the
 #'  model fit call. For this type of
 #'  model, the template of the fit calls are:
@@ -63,7 +70,7 @@
 #' on new data. This also means that a single value of that function's
 #' `kernel` argument (a.k.a `weight_func` here) can be supplied
 #'
-#' @seealso [[fit()]
+#' @seealso [fit()]
 #'
 #' @examples
 #' nearest_neighbor(neighbors = 11)
@@ -157,11 +164,11 @@ check_args.nearest_neighbor <- function(object) {
   args <- lapply(object$args, rlang::eval_tidy)
 
   if (is.numeric(args$neighbors) && !positive_int_scalar(args$neighbors)) {
-    stop("`neighbors` must be a length 1 positive integer.", call. = FALSE)
+    rlang::abort("`neighbors` must be a length 1 positive integer.")
   }
 
   if (is.character(args$weight_func) && length(args$weight_func) > 1) {
-    stop("The length of `weight_func` must be 1.", call. = FALSE)
+    rlang::abort("The length of `weight_func` must be 1.")
   }
 
   invisible(object)
@@ -197,7 +204,7 @@ translate.nearest_neighbor <- function(x, engine = x$engine, ...) {
 multi_predict._train.kknn <-
   function(object, new_data, type = NULL, neighbors = NULL, ...) {
     if (any(names(enquos(...)) == "newdata"))
-      stop("Did you mean to use `new_data` instead of `newdata`?", call. = FALSE)
+      rlang::abort("Did you mean to use `new_data` instead of `newdata`?")
 
     if (is.null(neighbors))
       neighbors <- rlang::eval_tidy(object$fit$call$ks)
