@@ -65,8 +65,12 @@ ranger_confint <- function(object, new_data, ...) {
     if (object$fit$forest$treetype == "Probability estimation") {
       res <- ranger_class_confint(object, new_data, ...)
     } else {
-      stop("Cannot compute confidence intervals for a ranger forest ",
-           "of type ", object$fit$forest$treetype, ".", call. = FALSE)
+      rlang::abort(
+        glue::glue(
+          "Cannot compute confidence intervals for a ranger forest ",
+          "of type {object$fit$forest$treetype}."
+        )
+      )
     }
   }
   res
@@ -173,10 +177,11 @@ set_pred(
   value = list(
     pre = function(x, object) {
       if (object$fit$forest$treetype != "Probability estimation")
-        stop(
-          "`ranger` model does not appear to use class probabilities. Was ",
-          "the model fit with `probability = TRUE`?",
-          call. = FALSE
+        rlang::abort(
+          glue::glue(
+            "`ranger` model does not appear to use class probabilities. Was ",
+            "the model fit with `probability = TRUE`?"
+          )
         )
       x
     },
@@ -214,7 +219,7 @@ set_pred(
 )
 
 set_pred(
-  mod = "rand_forest",
+  model = "rand_forest",
   eng = "ranger",
   mode = "classification",
   type = "raw",
@@ -254,7 +259,7 @@ set_pred(
 
 
 set_pred(
-  mod = "rand_forest",
+  model = "rand_forest",
   eng = "ranger",
   mode = "regression",
   type = "conf_int",
