@@ -6,6 +6,7 @@ library(tidyr)
 # ------------------------------------------------------------------------------
 
 context("linear regression execution with glmnet")
+source("helper-objects.R")
 
 num_pred <- c("Sepal.Width", "Petal.Width", "Petal.Length")
 iris_bad_form <- as.formula(Species ~ term)
@@ -14,15 +15,12 @@ iris_basic <- linear_reg(penalty = .1, mixture = .3) %>%
 no_lambda <- linear_reg(mixture = .3) %>%
   set_engine("glmnet")
 
-ctrl <- control_parsnip(verbosity = 1, catch = FALSE)
-caught_ctrl <- control_parsnip(verbosity = 1, catch = TRUE)
-quiet_ctrl <- control_parsnip(verbosity = 0, catch = TRUE)
-
 # ------------------------------------------------------------------------------
 
 test_that('glmnet execution', {
 
   skip_if_not_installed("glmnet")
+  skip_if(run_glmnet)
 
   expect_error(
     res <- fit_xy(
@@ -59,6 +57,7 @@ test_that('glmnet execution', {
 test_that('glmnet prediction, single lambda', {
 
   skip_if_not_installed("glmnet")
+  skip_if(run_glmnet)
 
   res_xy <- fit_xy(
     iris_basic,
@@ -89,6 +88,7 @@ test_that('glmnet prediction, single lambda', {
 test_that('glmnet prediction, multiple lambda', {
 
   skip_if_not_installed("glmnet")
+  skip_if(run_glmnet)
 
   lams <- c(.01, 0.1)
 
@@ -185,6 +185,7 @@ test_that('glmnet prediction, multiple lambda', {
 test_that('glmnet prediction, all lambda', {
 
   skip_if_not_installed("glmnet")
+  skip_if(run_glmnet)
 
   iris_all <- linear_reg(mixture = .3) %>%
     set_engine("glmnet")
@@ -233,6 +234,7 @@ test_that('glmnet prediction, all lambda', {
 test_that('submodel prediction', {
 
   skip_if_not_installed("glmnet")
+  skip_if(run_glmnet)
 
   reg_fit <-
     linear_reg() %>%
@@ -275,6 +277,7 @@ test_that('submodel prediction', {
 test_that('error traps', {
 
   skip_if_not_installed("glmnet")
+  skip_if(run_glmnet)
 
   expect_error(
     linear_reg() %>%
