@@ -5,10 +5,7 @@ library(dplyr)
 # ------------------------------------------------------------------------------
 
 context("logistic regression execution with spark")
-
-ctrl <- control_parsnip(verbosity = 1, catch = FALSE)
-caught_ctrl <- control_parsnip(verbosity = 1, catch = TRUE)
-quiet_ctrl <- control_parsnip(verbosity = 0, catch = TRUE)
+source("helper-objects.R")
 
 # ------------------------------------------------------------------------------
 
