@@ -6,6 +6,7 @@ library(rlang)
 
 context("mars tests")
 source("helpers.R")
+source("helper-objects.R")
 
 # ------------------------------------------------------------------------------
 
@@ -124,10 +125,6 @@ num_pred <- c("Sepal.Width", "Petal.Width", "Petal.Length")
 iris_bad_form <- as.formula(Species ~ term)
 iris_basic <- mars(mode = "regression") %>% set_engine("earth")
 
-ctrl <- control_parsnip(verbosity = 1, catch = FALSE)
-caught_ctrl <- control_parsnip(verbosity = 1, catch = TRUE)
-quiet_ctrl <- control_parsnip(verbosity = 0, catch = TRUE)
-
 # ------------------------------------------------------------------------------
 
 test_that('mars execution', {
@@ -288,8 +285,6 @@ test_that('submodel prediction', {
 
 # ------------------------------------------------------------------------------
 
-data("lending_club")
-
 test_that('classification', {
   skip_if_not_installed("earth")
 
