@@ -4,6 +4,7 @@ library(parsnip)
 # ------------------------------------------------------------------------------
 
 context("simple neural network execution with nnet")
+source("helper-objects.R")
 
 num_pred <- names(iris)[1:4]
 
@@ -11,10 +12,6 @@ iris_nnet <-
   mlp(mode = "classification", hidden_units = 5) %>%
   set_engine("nnet")
 
-ctrl <- control_parsnip(verbosity = 1, catch = FALSE)
-caught_ctrl <- control_parsnip(verbosity = 1, catch = TRUE)
-quiet_ctrl <- control_parsnip(verbosity = 0, catch = TRUE)
-
 # ------------------------------------------------------------------------------
 
 test_that('nnet execution, classification', {
@@ -94,10 +91,6 @@ bad_rf_reg <-
   mlp(mode = "regression") %>%
   set_engine("nnet", sampsize = -10)
 
-ctrl <- list(verbosity = 1, catch = FALSE)
-caught_ctrl <- list(verbosity = 1, catch = TRUE)
-quiet_ctrl <- list(verbosity = 0, catch = TRUE)
-
 # ------------------------------------------------------------------------------
 
 
