@@ -6,10 +6,7 @@ library(tibble)
 # ------------------------------------------------------------------------------
 
 context("multinom regression execution with glmnet")
-
-ctrl <- control_parsnip(verbosity = 1, catch = FALSE)
-caught_ctrl <- control_parsnip(verbosity = 1, catch = TRUE)
-quiet_ctrl <- control_parsnip(verbosity = 0, catch = TRUE)
+source("helper-objects.R")
 
 rows <- c(1, 51, 101)
 
@@ -18,6 +15,7 @@ rows <- c(1, 51, 101)
 test_that('glmnet execution', {
 
   skip_if_not_installed("glmnet")
+  skip_if(run_glmnet)
 
   expect_error(
     res <- fit_xy(
@@ -46,6 +44,7 @@ test_that('glmnet execution', {
 test_that('glmnet prediction, one lambda', {
 
   skip_if_not_installed("glmnet")
+  skip_if(run_glmnet)
 
   xy_fit <- fit_xy(
     multinom_reg(penalty = 0.1) %>% set_engine("glmnet"),
@@ -88,6 +87,7 @@ test_that('glmnet prediction, one lambda', {
 test_that('glmnet probabilities, mulitiple lambda', {
 
   skip_if_not_installed("glmnet")
+  skip_if(run_glmnet)
 
   lams <- c(0.01, 0.1)
 
@@ -152,6 +152,9 @@ test_that('glmnet probabilities, mulitiple lambda', {
 })
 
 test_that("class predictions are factors with all levels", {
+  skip_if_not_installed("glmnet")
+  skip_if(run_glmnet)
+
   basic <- multinom_reg() %>% set_engine("glmnet") %>% fit(Species ~ ., data = iris)
   nd <- iris[iris$Species == "setosa", ]
   yhat <- predict(basic, new_data = nd, penalty = .1)
